ToCef

Derive Macro ToCef 

#[derive(ToCef)]
This macro derives the ToCef trait on the annotated item. For now, the ToCef trait itself provides a useful implementation of the trait, so this macro simply implements a blank trait.